@@ -2,6 +2,19 @@
 更新内容一览
 """
 
+
+"""
+2022/10/07
+control_version:0.7.2
+blcoklyFile_version:2.2.10
+blockly_version:2.2.5
+1、整理了control库，增加了util文件夹存放各种工具
+2、增加了案例体验这个分支，增加了本地化语音、启动古诗生成器编程块，将词云编程块从画图转移到文本，将语音控制小车编程块从硬件控制转移到案例体验
+3、删除了integration.py并在readme中同步删除了跟integration.py有关的信息
+4、删除了lcd文件夹中没有用到的py文件
+5、更新了requirements
+"""
+
 """
 2022/9/22
 control_version:0.7.1
